@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
 import inspect
 import re
 from xml.sax.saxutils import quoteattr
 
-from . import validators as v
-from .utils import to_unicode
-
 from babel.dates import (format_date, format_datetime, format_time,
     parse_date, parse_datetime, parse_time)
 try:
@@ -14,6 +13,9 @@ except ImportError:
     Markup = unicode
 from pytz import utc
 
+from . import validators as v
+from ..serializers import to_unicode
+
 
 __all__ = (
     'Markup', 'ValidationError',
